import * as Models from './models';
import * as Parameters from './parameters';
import { Callback } from '../callback';
import { Client } from '../clients';
export declare class SpaceProperties {
    private client;
    constructor(client: Client);
    /**
     * Returns all properties for the given space. Space properties are a key-value storage associated with a space.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
     */
    getSpaceProperties<T = Models.SpacePropertyArray>(parameters: Parameters.GetSpaceProperties, callback: Callback<T>): Promise<void>;
    /**
     * Returns all properties for the given space. Space properties are a key-value storage associated with a space.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
     */
    getSpaceProperties<T = Models.SpacePropertyArray>(parameters: Parameters.GetSpaceProperties, callback?: never): Promise<T>;
    /**
     * Creates a new space property.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    createSpaceProperty<T = Models.SpaceProperty>(parameters: Parameters.CreateSpaceProperty, callback: Callback<T>): Promise<void>;
    /**
     * Creates a new space property.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    createSpaceProperty<T = Models.SpaceProperty>(parameters: Parameters.CreateSpaceProperty, callback?: never): Promise<T>;
    /**
     * Returns a space property.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
     */
    getSpaceProperty<T = Models.SpaceProperty>(parameters: Parameters.GetSpaceProperty, callback: Callback<T>): Promise<void>;
    /**
     * Returns a space property.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
     */
    getSpaceProperty<T = Models.SpaceProperty>(parameters: Parameters.GetSpaceProperty, callback?: never): Promise<T>;
    /**
     * Creates a new space property. This is the same as `POST /api/space/{spaceKey}/property` but the key for the
     * property is passed as a path parameter, rather than in the request body.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    createSpacePropertyForKey<T = Models.SpaceProperty>(parameters: Parameters.CreateSpacePropertyForKey, callback: Callback<T>): Promise<void>;
    /**
     * Creates a new space property. This is the same as `POST /api/space/{spaceKey}/property` but the key for the
     * property is passed as a path parameter, rather than in the request body.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    createSpacePropertyForKey<T = Models.SpaceProperty>(parameters: Parameters.CreateSpacePropertyForKey, callback?: never): Promise<T>;
    /**
     * Updates a space property. Note, you cannot update the key of a space property, only the value.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    updateSpaceProperty<T = Models.SpaceProperty>(parameters: Parameters.UpdateSpaceProperty, callback: Callback<T>): Promise<void>;
    /**
     * Updates a space property. Note, you cannot update the key of a space property, only the value.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    updateSpaceProperty<T = Models.SpaceProperty>(parameters: Parameters.UpdateSpaceProperty, callback?: never): Promise<T>;
    /**
     * Deletes a space property.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    deleteSpaceProperty<T = void>(parameters: Parameters.DeleteSpaceProperty, callback: Callback<T>): Promise<void>;
    /**
     * Deletes a space property.
     *
     * **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘Admin’ permission for the space.
     */
    deleteSpaceProperty<T = void>(parameters: Parameters.DeleteSpaceProperty, callback?: never): Promise<T>;
}
