import { AxiosError } from 'axios';
import type { RequestConfig } from './requestConfig';
import type { UtilityTypes } from './utilityTypes';
export interface Config {
    host: string;
    baseRequestConfig?: Config.BaseRequestConfig;
    authentication?: Config.Authentication;
    middlewares?: Config.Middlewares;
    /** @deprecated Disabled. Will be removed in the next major version. */
    telemetry?: Config.Telemetry;
    /** Adds `'X-Atlassian-Token': 'no-check'` to each request header */
    noCheckAtlassianToken?: boolean;
    /** Enable new API error handling. `false` by default. */
    newErrorHandling?: boolean;
    /** Prefix for all API routes. */
    apiPrefix?: string;
}
export declare namespace Config {
    type BaseRequestConfig = RequestConfig;
    type Error = AxiosError;
    /** @deprecated Disabled. Will be removed in the next major version. */
    type Telemetry = boolean | any;
    type Authentication = UtilityTypes.XOR4<{
        jwt: Authentication.JWT;
    }, {
        personalAccessToken: Authentication.PersonalAccessToken;
    }, {
        basic: Authentication.Basic;
    }, {
        oauth2: Authentication.OAuth2;
    }>;
    interface Middlewares {
        onError?: Config.Middlewares.OnErrorHandler;
        onResponse?: Config.Middlewares.OnResponseHandler;
    }
    namespace Middlewares {
        type OnErrorHandler = (error: Config.Error) => void;
        type OnResponseHandler = (data: any) => void;
    }
    namespace Authentication {
        type PersonalAccessToken = string;
        type JWT = {
            /** The key from the app descriptor. */
            issuer: string;
            /** The shared secret key received during the app installation handshake */
            secret: string;
            /** Token expiry time (default 3 minutes after issuing) */
            expiryTimeSeconds?: number;
        };
        type Basic = UtilityTypes.XOR<{
            email: string;
            apiToken: string;
        }, {
            username: string;
            password: string;
        }>;
        type OAuth2 = {
            accessToken: string;
        };
    }
}
